@@ -1,4 +1,4 @@
-"Combinations" <-
+Combinations <-
 function(n, k){
   # Compute all n choose k combinations of size k from 1:n
   # Return matrix with k rows and choose(n,k) columns.
